The team
========

HCIPy was originally developed by a small team of astronomers at Leiden Observatory, but has since received external constributions from scientists and software developers around the world.

Direct contributors to code
---------------------------
* Emiel Por (`@ehpor <https://github.com/ehpor>`__), Space Telescope Science Institute
* Sebastiaan Haffert (`@syhaffert <https://github.com/syhaffert>`__), University of Arizona
* Steven Bos (`@spbos <https://github.com/spbos>`__), Leiden Observatory
* Maaike van Kooten (`@vkooten <https://github.com/vkooten>`__), NRC Herzberg
* Vikram Radhakrishnan (`@VikramRadhakrishnan <https://github.com/VikramRadhakrishnan>`__), Leiden Observatory
* David Doelman (`@dsdoelman <https://github.com/dsdoelman>`__), Leiden Observatory
* Christoph Keller (`@cukeller <https://github.com/cukeller>`__), Lowell Observatory
* Iva Laginja (`@ivalaginja <https://github.com/ivalaginja>`__), Université de Paris
* Jamie Noss (`@jamienoss <https://github.com/jamienoss>`__), Space Telescope Science Institute
* Rémi Soummer (`@RemiSoummer <https://github.com/RemiSoummer>`__), Space Telescope Science Institute
* Kathryn St Laurent (`@kstlaurent <https://github.com/kstlaurent>`__), Space Telescope Science Institute
* Matthew Kenworthy (`@mkenworthy <https://github.com/mkenworthy>`__), Leiden Observatory
* David Kleingeld (`@dskleingeld <https://github.com/dskleingeld>`__), Leiden Observatory
* Gilles Orban de Xivry (`@GillesOrban <https://github.com/GillesOrban>`__), Université de Liège
* Brett Graham (`@braingram <https://github.com/braingram>`__), Space Telescope Science Institute

Testing and QA
--------------
* Rebecca Jensen-Clem (`@rmjc <https://github.com/rmjc>`__), University of California Santa Cruz
* Aditya Sengupta (`@aditya-sengupta <https://github.com/aditya-sengupta>`__), University of California Santa Cruz
* Fedde Fagginger Auer (`@fjfaggingerauer <https://github.com/fjfaggingerauer>`__), Leiden Observatory
* Joost Wardenier (`@joostwardenier <https://github.com/joostwardenier>`__), University of Oxford
* Raphaël Pourcelot (`@raphaelpclt <https://github.com/raphaelpclt>`__), Space Telescope Science Institute

Contributing
------------

If you would like to contribute to the development of HCIPy, we refer you to the :doc:`contributing guide <development/contributing_guide>`. Contributions can be as small as reporting a bug.
